.onLoad <-
function (lib, pkg) 
library.dynam("bestglm", pkg, lib)
